pub fn spawn_download_worker(
config: Config,
download_rx: Receiver<DownloadCommand>,
status_tx: Sender<WorkerToGuiMessage>,
) -> JoinHandle<()>Expand description
Spawn the blocking download worker used by the desktop GUI.
pub fn spawn_download_worker(
config: Config,
download_rx: Receiver<DownloadCommand>,
status_tx: Sender<WorkerToGuiMessage>,
) -> JoinHandle<()>Spawn the blocking download worker used by the desktop GUI.