auto_extract

Function auto_extract 

pub fn auto_extract(
    path: &Path,
    quiet: bool,
) -> Result<(), Box<dyn Error + Send + Sync>>
Extract an archive at path into its parent directory using the system tool (unzip, tar, or 7z). Returns Ok(()) if the path is not a recognised archive type (no-op) or if extraction succeeds.

Errors

Returns an error if the tool is not found or exits with a non-zero status.